@@ -14,6 +14,7 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/platform"
 	"github.com/jandedobbeleer/oh-my-posh/src/properties"
 	"github.com/jandedobbeleer/oh-my-posh/src/segments"
+	"github.com/jandedobbeleer/oh-my-posh/src/shell"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 
 	"github.com/gookit/config/v2"
@@ -48,6 +49,7 @@ type Config struct {
 	Palette              ansi.Palette           `json:"palette,omitempty"`
 	Palettes             *ansi.Palettes         `json:"palettes,omitempty"`
 	Cycle                ansi.Cycle             `json:"cycle,omitempty"`
+	ShellIntegration     bool                   `json:"shell_integration,omitempty"`
 	PWD                  string                 `json:"pwd,omitempty"`
 	Var                  map[string]interface{} `json:"var,omitempty"`
 
@@ -90,10 +92,30 @@ func (cfg *Config) getPalette() ansi.Palette {
 // LoadConfig returns the default configuration including possible user overrides
 func LoadConfig(env platform.Environment) *Config {
 	cfg := loadConfig(env)
+
 	// only migrate automatically when the switch isn't set
 	if !env.Flags().Migrate && cfg.Version < configVersion {
 		cfg.BackupAndMigrate()
 	}
+
+	if !cfg.ShellIntegration {
+		return cfg
+	}
+
+	// bash  - ok
+	// fish  - ok
+	// pwsh  - ok
+	// zsh   - ok
+	// cmd   - ok, as of v1.4.25 (chrisant996/clink#457, fixed in chrisant996/clink@8a5d7ea)
+	// nu    - built-in (and bugged) feature - nushell/nushell#5585, https://www.nushell.sh/blog/2022-08-16-nushell-0_67.html#shell-integration-fdncred-and-tyriar
+	// elv   - broken OSC sequences
+	// xonsh - broken OSC sequences
+	// tcsh  - overall broken, FTCS_COMMAND_EXECUTED could be added to POSH_POSTCMD in the future
+	switch env.Shell() {
+	case shell.ELVISH, shell.XONSH, shell.TCSH, shell.NU:
+		cfg.ShellIntegration = false
+	}
+
 	return cfg
 }
 
@@ -270,8 +292,12 @@ func escapeGlyphs(s string, migrate bool) string {
 	}
 
 	var cp codePoints
+	var err error
 	if migrate {
-		cp = getGlyphCodePoints()
+		cp, err = getGlyphCodePoints()
+		if err != nil {
+			migrate = false
+		}
 	}
 
 	var builder strings.Builder
@@ -325,7 +351,7 @@ func defaultConfig(env platform.Environment, warning bool) *Config {
 						TrailingDiamond: "\ue0b0",
 						Background:      "p:yellow",
 						Foreground:      "p:black",
-						Template:        " {{ if .SSHSession }}\uf817 {{ end }}{{ .UserName }} ",
+						Template:        " {{ if .SSHSession }}\ueba9 {{ end }}{{ .UserName }} ",
 					},
 					{
 						Type:            PATH,
@@ -336,7 +362,7 @@ func defaultConfig(env platform.Environment, warning bool) *Config {
 						Properties: properties.Map{
 							properties.Style: "folder",
 						},
-						Template: " \uf74a {{ path .Path .Location }} ",
+						Template: " \uea83 {{ path .Path .Location }} ",
 					},
 					{
 						Type:            GIT,
@@ -359,7 +385,6 @@ func defaultConfig(env platform.Environment, warning bool) *Config {
 							segments.BranchMaxLength:   25,
 							segments.FetchStatus:       true,
 							segments.FetchUpstreamIcon: true,
-							segments.GithubIcon:        "\uf7a3",
 						},
 						Template: " {{ if .UpstreamURL }}{{ url .UpstreamIcon .UpstreamURL }} {{ end }}{{ .HEAD }}{{if .BranchStatus }} {{ .BranchStatus }}{{ end }}{{ if .Working.Changed }} \uf044 {{ .Working.String }}{{ end }}{{ if .Staging.Changed }} \uf046 {{ .Staging.String }}{{ end }} ", //nolint:lll
 					},
@@ -396,7 +421,7 @@ func defaultConfig(env platform.Environment, warning bool) *Config {
 						Style:      Plain,
 						Background: "transparent",
 						Foreground: "p:green",
-						Template:   "\uf898 ",
+						Template:   "\ue718 ",
 						Properties: properties.Map{
 							segments.HomeEnabled:         false,
 							segments.FetchPackageManager: false,
@@ -408,7 +433,7 @@ func defaultConfig(env platform.Environment, warning bool) *Config {
 						Style:      Plain,
 						Background: "transparent",
 						Foreground: "p:blue",
-						Template:   "\ufcd1 ",
+						Template:   "\ue626 ",
 						Properties: properties.Map{
 							properties.FetchVersion: false,
 						},
