@@ -10,7 +10,7 @@ import (
 
 type codePoints map[int]int
 
-func getGlyphCodePoints() codePoints {
+func getGlyphCodePoints() (codePoints, error) {
 	var codePoints = make(codePoints)
 
 	client := &http.Client{}
@@ -19,19 +19,19 @@ func getGlyphCodePoints() codePoints {
 
 	request, err := http.NewRequestWithContext(ctx, http.MethodGet, "https://ohmyposh.dev/codepoints.csv", nil)
 	if err != nil {
-		return codePoints
+		return codePoints, &ConnectionError{reason: err.Error()}
 	}
 
 	response, err := client.Do(request)
 	if err != nil {
-		return codePoints
+		return codePoints, err
 	}
 
 	defer response.Body.Close()
 
 	lines, err := csv.NewReader(response.Body).ReadAll()
 	if err != nil {
-		return codePoints
+		return codePoints, err
 	}
 
 	for _, line := range lines {
@@ -48,5 +48,5 @@ func getGlyphCodePoints() codePoints {
 		}
 		codePoints[int(oldGlyph)] = int(newGlyph)
 	}
-	return codePoints
+	return codePoints, nil
 }
